@@ -177,22 +177,22 @@ class KinesisStreamsToLambda(
 
         jsii.create(KinesisStreamsToLambda, self, [scope, id, props])
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
-        return jsii.get(self, "kinesisStream")
+        return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return jsii.get(self, "lambdaFunction")
+        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
     ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
-        return jsii.get(self, "cloudwatchAlarms")
+        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
 
 @jsii.data_type(
@@ -264,7 +264,7 @@ class KinesisStreamsToLambdaProps:
         :default: - Alarms are created
         """
         result = self._values.get("create_cloud_watch_alarms")
-        return result
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def deploy_sqs_dlq_queue(self) -> typing.Optional[builtins.bool]:
@@ -273,7 +273,7 @@ class KinesisStreamsToLambdaProps:
         :default: - true.
         """
         result = self._values.get("deploy_sqs_dlq_queue")
-        return result
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
@@ -282,7 +282,7 @@ class KinesisStreamsToLambdaProps:
         :default: - None
         """
         result = self._values.get("existing_lambda_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
     @builtins.property
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
@@ -291,7 +291,7 @@ class KinesisStreamsToLambdaProps:
         :default: - None
         """
         result = self._values.get("existing_stream_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
 
     @builtins.property
     def kinesis_event_source_props(self) -> typing.Any:
@@ -300,7 +300,7 @@ class KinesisStreamsToLambdaProps:
         :default: - Default props are used.
         """
         result = self._values.get("kinesis_event_source_props")
-        return result
+        return typing.cast(typing.Any, result)
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
@@ -309,7 +309,7 @@ class KinesisStreamsToLambdaProps:
         :default: - Default props are used.
         """
         result = self._values.get("kinesis_stream_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.StreamProps], result)
 
     @builtins.property
     def lambda_function_props(
@@ -320,7 +320,7 @@ class KinesisStreamsToLambdaProps:
         :default: - Default props are used.
         """
         result = self._values.get("lambda_function_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
     @builtins.property
     def sqs_dlq_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
@@ -329,7 +329,7 @@ class KinesisStreamsToLambdaProps:
         :default: - Default props are used
         """
         result = self._values.get("sqs_dlq_queue_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
